==> dvdisaster_0.71.26.orig.tar.gz: dvdisaster-0.71.26/documentation/ru/index20.php <==
<?php
# dvdisaster: Russian homepage translation
# Copyright (C) 2007-2008 Igor Gorbounov
#
# UTF-8 trigger: äöüß 
#
# Include our PHP sub routines, then call begin_page()
# to start the HTML page, insert the header, 
# navigation and news if appropriate.

require("../include/dvdisaster.php");
begin_page();
?>

<!--- Insert actual page content below --->

<h3>dvdisaster как дополнение к проверке качества носителя</h3>

<a href="qa.php#pipo">Проверка качества носителя</a>, например, проверка на ошибки C2 или PI/PO, являются ценным  
инструментом проверки результатов процесса записи носителей.<p>

Но проверка качества <b>не</b> является надежным средством <b>предсказания 
срока службы </b> оптических носителей. <br>
Предположим, что мы ищем правильное время
для копирования изношенного носителя на новый:

<ul>
<li>Слишком рано: Копирование носителя из-за плохого результата проверки качества неэффективно с экономической точки зрения.
Иногда такой носитель остается читаемым намного дольше, чем ожидалось.<p></li>
<li>Слишком поздно: Когда проверка качества носителя обнаруживает нечитаемые сектора, некоторые
данные уже потеряны.<p></li>
<li>Как раз перед отказом носителя: Идеальный случай, но как узнать?
</ul>

Однако, мы могли бы сделать это путем dvdisaster:

<ul>
<li><a href="howtos20.php">Создать данные для исправления ошибок</a> для носителя.<p></li>
<li><a href="howtos10.php">Проверять носитель</a> регулярно. Использовать его до появления первых ошибок чтения.<p></li>
<li><a href="howtos30.php">Восстановить</a> места с ошибками чтения, <a href="howtos40.php">используя данные для исправления ошибок</a>.
Записать восстановленный образ на новый носитель.</li>
</ul>

<p>
<a href="index30.php">dvdisaster: за и против при беглом взгляде...</a>

<!--- do not change below --->

<?php
# end_page() adds the footer line and closes the HTML properly.

end_page();
?>

==> dvdisaster_0.72.1.orig.tar.gz: dvdisaster-0.72.1.orig/documentation/ru/index20.php <==
<?php
# dvdisaster: Russian homepage translation
# Copyright (C) 2007-2009 Igor Gorbounov
#
# UTF-8 trigger: äöüß 
#
# Include our PHP sub routines, then call begin_page()
# to start the HTML page, insert the header, 
# navigation and news if appropriate.

require("../include/dvdisaster.php");
begin_page();
?>

<!--- Insert actual page content below --->

<h3>dvdisaster как дополнение к проверке качества носителя</h3>

<a href="qa.php#pipo">Проверка качества носителя</a>, например, проверка на ошибки C2 или PI/PO, являются ценным  
инструментом проверки результатов процесса записи носителей.<p>

Но проверка качества <b>не</b> является надежным средством <b>предсказания 
срока службы </b> оптических носителей. <br>
Предположим, что мы ищем правильное время
для копирования изношенного носителя на новый:

<ul>
<li>Слишком рано: Копирование носителя из-за плохого результата проверки качества неэффективно с экономической точки зрения.
Иногда такой носитель остается читаемым намного дольше, чем ожидалось.<p></li>
<li>Слишком поздно: Когда проверка качества носителя обнаруживает нечитаемые сектора, некоторые
данные уже потеряны.<p></li>
<li>Как раз перед отказом носителя: Идеальный случай, но как узнать?
</ul>

Однако, мы могли бы сделать это так, как предлагает dvdisaster:

<ul>
<li><a href="howtos20.php">Создать данные для исправления ошибок</a> для носителя.<p></li>
<li><a href="howtos10.php">Проверять носитель</a> регулярно. Использовать его до появления первых ошибок чтения.<p></li>
<li><a href="howtos30.php">Восстановить</a> места с ошибками чтения, <a href="howtos40.php">используя данные для исправления ошибок</a>.
Записать восстановленный образ на новый носитель.</li>
</ul>

<p>
<a href="index30.php">dvdisaster: за и против при беглом взгляде...</a>

<!--- do not change below --->

<?php
# end_page() adds the footer line and closes the HTML properly.

end_page();
?>
